summaryrefslogtreecommitdiffstats
path: root/examples/h5_extlink.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2006-10-31 00:45:31 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2006-10-31 00:45:31 (GMT)
commit8b52aae45d4c461644657ee9be2a3e092006887e (patch)
treeefb4ff2d0cb5e6b5292b3286c13cf97e3a618419 /examples/h5_extlink.c
parent5acf9725e0586f66427d69c095f9741abf182946 (diff)
downloadhdf5-8b52aae45d4c461644657ee9be2a3e092006887e.zip
hdf5-8b52aae45d4c461644657ee9be2a3e092006887e.tar.gz
hdf5-8b52aae45d4c461644657ee9be2a3e092006887e.tar.bz2
[svn-r12835] Description:
Change H5Lget_linkinfo() to H5Lget_info() to better align with coming API changes. Tested on: Linux/32 2.6 (chicago) Linux/64 2.6 (chicago2)
Diffstat (limited to 'examples/h5_extlink.c')
-rw-r--r--examples/h5_extlink.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/h5_extlink.c b/examples/h5_extlink.c
index 45dc01f..edf7609 100644
--- a/examples/h5_extlink.c
+++ b/examples/h5_extlink.c
@@ -312,7 +312,7 @@ void hard_link_example()
{
hid_t file_id;
hid_t group_id;
- H5L_linkinfo_t li;
+ H5L_info_t li;
/* Define the link class that we'll use to register "user-defined hard
* links" using the callbacks we defined above.
* A link class can have NULL for any callback except its traverse
@@ -354,10 +354,10 @@ void hard_link_example()
H5Lregister(UD_hard_class);
/* Since hard links link by object address, we'll need to retrieve
* the target group's address. We do this by calling H5Lget_linkinfo
* on a hard link to the object.
*/
- H5Lget_linkinfo(file_id, TARGET_GROUP, &li, H5P_DEFAULT);
+ H5Lget_info(file_id, TARGET_GROUP, &li, H5P_DEFAULT);
/* Now create a user-defined link. We give it the group's address
* as its udata.
@@ -354,10 +354,10 @@ void hard_link_example()
H5Lregister(UD_hard_class);
/* Since hard links link by object address, we'll need to retrieve
- * the target group's address. We do this by calling H5Lget_linkinfo
+ * the target group's address. We do this by calling H5Lget_info
* on a hard link to the object.
*/